
#ifndef KCMUTILSQUICK_EXPORT_H
#define KCMUTILSQUICK_EXPORT_H

#ifdef KCMUTILSQUICK_STATIC_DEFINE
#  define KCMUTILSQUICK_EXPORT
#  define KCMUTILSQUICK_NO_EXPORT
#else
#  ifndef KCMUTILSQUICK_EXPORT
#    ifdef KF6KCMUtilsQuick_EXPORTS
        /* We are building this library */
#      define KCMUTILSQUICK_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCMUTILSQUICK_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCMUTILSQUICK_NO_EXPORT
#    define KCMUTILSQUICK_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCMUTILSQUICK_DECL_DEPRECATED
#  define KCMUTILSQUICK_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCMUTILSQUICK_DECL_DEPRECATED_EXPORT
#  define KCMUTILSQUICK_DECL_DEPRECATED_EXPORT KCMUTILSQUICK_EXPORT KCMUTILSQUICK_DECL_DEPRECATED
#endif

#ifndef KCMUTILSQUICK_DECL_DEPRECATED_NO_EXPORT
#  define KCMUTILSQUICK_DECL_DEPRECATED_NO_EXPORT KCMUTILSQUICK_NO_EXPORT KCMUTILSQUICK_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCMUTILSQUICK_NO_DEPRECATED
#    define KCMUTILSQUICK_NO_DEPRECATED
#  endif
#endif

#define KCMUTILSQUICK_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KCMUTILSQUICK_NO_DEPRECATED) && !defined(KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCMUTILSQUICK_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCMUTILSQUICK_NO_DEPRECATED_WARNINGS) && !defined(KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCMUTILSQUICK_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCMUTILSQUICK_NO_DEPRECATED)
#  undef KCMUTILSQUICK_DEPRECATED
#  define KCMUTILSQUICK_DEPRECATED_EXPORT KCMUTILSQUICK_EXPORT
#  define KCMUTILSQUICK_DEPRECATED_NO_EXPORT KCMUTILSQUICK_NO_EXPORT
#elif defined(KCMUTILSQUICK_NO_DEPRECATED_WARNINGS)
#  define KCMUTILSQUICK_DEPRECATED
#  define KCMUTILSQUICK_DEPRECATED_EXPORT KCMUTILSQUICK_EXPORT
#  define KCMUTILSQUICK_DEPRECATED_NO_EXPORT KCMUTILSQUICK_NO_EXPORT
#else
#  define KCMUTILSQUICK_DEPRECATED KCMUTILSQUICK_DECL_DEPRECATED
#  define KCMUTILSQUICK_DEPRECATED_EXPORT KCMUTILSQUICK_DECL_DEPRECATED_EXPORT
#  define KCMUTILSQUICK_DEPRECATED_NO_EXPORT KCMUTILSQUICK_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCMUTILSQUICK_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCMUTILSQUICK_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCMUTILSQUICK_NO_DEPRECATED
#  define KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0x61100
#endif
#ifdef KCMUTILSQUICK_NO_DEPRECATED_WARNINGS
#  define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE
#  ifdef KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCMUTILSQUICK_DEPRECATED_WARNINGS_SINCE 0x61100
#  endif
#endif

#ifndef KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCMUTILSQUICK_DEPRECATED
#  define KCMUTILSQUICK_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCMUTILSQUICK_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCMUTILSQUICK_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KCMUTILSQUICK_EXPORT_H */
